import type { InitMessage } from './protocol.ts';
export declare function adaptInitMessageForLocalTui(init: InitMessage, options: {
    isRemoteSession: boolean;
}): InitMessage;
//# sourceMappingURL=local-init-filter.d.ts.map