import { ExtensionAPI } from '@earendil-works/pi-coding-agent';
export declare function agentuityCoderHub(pi: ExtensionAPI): void;
export default agentuityCoderHub;
//# sourceMappingURL=index.d.ts.map