export declare function resolveCoderOrgId(orgId?: string | null): string | null;
export declare function isHubApiKey(apiKey?: string | null): boolean;
export declare function applyCoderAuthHeaders(headers: Record<string, string>, apiKey?: string | null, orgId?: string | null): Record<string, string>;
export declare function getCoderAuthCurlArgs(apiKey?: string | null, orgId?: string | null): string[];
//# sourceMappingURL=auth.d.ts.map