import type { ExtensionContext } from '@earendil-works/pi-coding-agent';
export declare function setNativeRemoteExtensionContext(ctx: ExtensionContext | null): void;
export declare function getNativeRemoteExtensionContext(): ExtensionContext | null;
export declare function waitForNativeRemoteExtensionContext(timeoutMs?: number): Promise<ExtensionContext | null>;
//# sourceMappingURL=native-remote-ui-context.d.ts.map