import type { Todo } from './types.ts';
export declare function createTodo(text: string): Todo;
export declare function listTodos(): Todo[];
export declare function completeTodo(id: string): Todo;
export declare function deleteTodo(id: string): Todo;
//# sourceMappingURL=store.d.ts.map